****************************************************************************
* The impact of bodyweight on life satisfaction among school-aged children:
*     Are the mechanisms gender-based?
* Do file to replicate the main results
* By: Mauricio Sarrias
*****************************************************************************

*** Globals 
global data  "/Users/mauriciosarrias/Dropbox/work/Health/Child development/Happiness&BMI/Submission-ISCI/ReplicationISCI"
global out   "/Users/mauriciosarrias/Dropbox/work/Health/Child development/Happiness&BMI/Submission-ISCI/ReplicationISCI"

*** Open dataset 
use "$data/elpi_isci.dta", clear 

*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
** Figure 1: Distribution of LS for girls and boys
*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

* Flag sample used in the main regressions
global child "age_eval c.age_eval#c.age_eval nolders nyounger" 
global house "i.region lninc hsize i.f_inhouse meals"
global care  "i.hhead i.civil2 age_care sch_care cesd10_int smoke drink2 drug2 breastf dep_post "
reg lsat $child $house $care  zbmi_child
gen flag1 = 1 if e(sample)

* Graph
tab lsat, gen(sf)
graph bar (mean) sf1 (mean) sf2 (mean) sf3 (mean) sf4 (mean) sf5 (mean) sf6 (mean) sf7 if flag1 == 1, ///
		blabel(bar, format(%9.2g)) bargap(30) ///
		legend(order(1 "Very unsatisfied with life" 7 "Very satisfied with life")) ///
		scheme(s1mono) over(sexchild, relabel(1 "Girls" 2 "Boys")) 
graph export "$out/histo.eps", replace


*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
** Table 1: Summary statistics
*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

* Generate dummy variables and globals
tabulate civil2, gen(cv)
tabulate drink, gen(dk)
tabulate drug, gen(dg)
global children "lsat weight height bmi_child  zbmi_child obese age_eval nolders nyounger " 
global household "f_inhouse lninc hsize meals"
global maternal "sch_care age_care hhead cv* cesd10_int dep_post smoke drink2 drug2 breastf "
global instr    "Lbmi_care"
global media    "tae_apariencia eclis_total obs_ill"

eststo clear 
estpost tabstat $children $household $maternal $instr $media if flag1 == 1, by(sexchild) nototal columns(statistics) statistics(mean sd count)
esttab . using "$out/table_sum.tex", replace ///
		cells("mean(fmt(2)) sd(fmt(2)) count(fmt(0))") ///
          collabels("\multicolumn{1}{c}{Mean}" "\multicolumn{1}{c}{SD}" "\multicolumn{1}{c}{N}", span ) ///
		  title("Summary statistics\label{tab:summary}") ///
		  eqlabels("Girls" "Boys", pattern(1 0 0 1 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///
		 coeflabels(lsat  "Life satisfaction" ///
		          weight "Weight" ///
				  height "Height" ///
				  bmi_child   "Child's BMI" ///
				  zbmi_child  "Child's z-BMI" ///
				  obese  "Obese" ///
				  age_eval "Child's age in months" ///
				  nolders "Number of older siblings" ///
				  nyounger "Number of younger siblings" ///
				  lninc "ln(Household income)" ///
				  hsize "Household size" ///
				  sch_care "Education (in years)" ///
				  age_care "Age (in years)" ///
				  cv1 "Married" ///
				  cv2 "Cohabitating" ///
				  cv3 "Separated/divorce" ///
				  cv4 "Single" ///
				  cv5 "Widowed" ///
				  hhead "Household head" ///
				  cesd10_int "Depression in 2017" ///
				  meals "Number of meals with family" ///
				  dep_post "Post-partum depression" ///
				  smoke "Smoked during pregancy" ///
				  drug2 "Used drugs during pregnancy" ///
				  drink2 "Drunk during pregnancy" ///
				  f_inhouse "Father in the house" ///  
				  Lbmi_care "Mother's BMI in 2012" ///
				  tae_apariencia "BI satisfaction" ///
				  breastf "Month of breastfeeding" ///
				  eclis_total "Bullying score" ///
				  obs_ill "Comorbidities") ///
		refcat(lsat  "\textbf{Children covariates:}" ///
		       f_inhouse "\textbf{Hosehold covariates:}" ///
			   sch_care  "\textbf{Mother's covariates:}" ///
			   Lbmi_care "\textbf{Instrument:}" ///
			   tae_apariencia "\textbf{Mediators:}", nolabel) ///
		  unstack nonumbers compress nogap booktabs nolabel longtable

*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
** Table 2: Bodyweight and mediator variables: OLS specifications ********
*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

global child "age_eval c.age_eval#c.age_eval nolders nyounger" 
global house "i.region lninc hsize i.f_inhouse meals"
global care  "i.hhead i.civil2 age_care sch_care cesd10_int smoke drink2 drug2 breastf dep_post"

* z-BMI
local se  vce(cluster region)
local sample if lsat != .

est clear
eststo: reg tae_apariencia	$child $house $care zbmi_child `sample'                , `se'
eststo: reg eclis_total  	$child $house $care zbmi_child `sample'                , `se'
eststo: reg obs_ill      	$child $house $care zbmi_child `sample'                , `se'
eststo: reg tae_apariencia	$child $house $care zbmi_child `sample' & sexchild == 0, `se'
eststo: reg eclis_total  	$child $house $care zbmi_child `sample' & sexchild == 0, `se'
eststo: reg obs_ill      	$child $house $care zbmi_child `sample' & sexchild == 0, `se'
eststo: reg tae_apariencia	$child $house $care zbmi_child `sample' & sexchild == 1, `se'
eststo: reg eclis_total  	$child $house $care zbmi_child `sample' & sexchild == 1, `se'
eststo: reg obs_ill      	$child $house $care zbmi_child `sample' & sexchild == 1, `se'
esttab using "$out/weightmed.tex", replace f  ///
		b(3) se(3) star(* 0.10 ** 0.05 *** 0.01) ///
		keep(zbmi_child) coeflabel(zbmi_child "z-BMI") ///
		booktabs nonotes collabels(none) alignment(D{.}{.}{-1}) longtable nolines posthead(\hline Panel A \\) compress nogap nodepvar  ///
		stats(N r2_a, fmt(%9.0gc %-9.3f) labels("N" "R2")) ///
		mgroups("All" "Girls" "Boys", pattern(1 0 0  1 0 0 1 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///
		mtitles("BIS" "Bullying" "Bad health" "BIS" "Bullying" "Bad health" "BIS" "Bullying" "Bad health")
		  
* Obese
est clear
eststo: reg tae_apariencia	$child $house $care obese `sample'                , `se'
eststo: reg eclis_total  	$child $house $care obese `sample'                , `se'
eststo: reg obs_ill      	$child $house $care obese `sample'                , `se'
eststo: reg tae_apariencia	$child $house $care obese `sample' & sexchild == 0, `se'
eststo: reg eclis_total  	$child $house $care obese `sample' & sexchild == 0, `se'
eststo: reg obs_ill      	$child $house $care obese `sample' & sexchild == 0, `se'
eststo: reg tae_apariencia	$child $house $care obese `sample' & sexchild == 1, `se'
eststo: reg eclis_total  	$child $house $care obese `sample' & sexchild == 1, `se'
eststo: reg obs_ill      	$child $house $care obese `sample' & sexchild == 1, `se'
esttab using "$out/weightmed.tex", append f  ///
		b(3) se(3) star(* 0.10 ** 0.05 *** 0.01) ///
		keep(obese) coeflabel(obese "Obese") ///
		label booktabs nonotes collabels(none) alignment(D{.}{.}{-1}) longtable nomtitle nolines nonum posthead(\hline Panel B \\)  compress nogap ///
		stats(N r2_a, fmt(%9.0gc %-9.3f) labels("N" "R2"))  
	  
* Weight
est clear
eststo: reg tae_apariencia	$child $house $care weight height `sample'                , `se'
eststo: reg eclis_total  	$child $house $care weight height `sample'                , `se'
eststo: reg obs_ill      	$child $house $care weight height `sample'                , `se'
eststo: reg tae_apariencia	$child $house $care weight height `sample' & sexchild == 0, `se'
eststo: reg eclis_total  	$child $house $care weight height `sample' & sexchild == 0, `se'
eststo: reg obs_ill      	$child $house $care weight height `sample' & sexchild == 0, `se'
eststo: reg tae_apariencia	$child $house $care weight height `sample' & sexchild == 1, `se'
eststo: reg eclis_total  	$child $house $care weight height `sample' & sexchild == 1, `se'
eststo: reg obs_ill      	$child $house $care weight height `sample' & sexchild == 1, `se'
esttab using "$out/weightmed.tex", append f  ///
	b(3) se(3) star(* 0.10 ** 0.05 *** 0.01) ///
	keep(weight height) coeflabel(weight "Weight" height "Height") ///
	label booktabs nonotes collabels(none) alignment(D{.}{.}{-1}) longtable nomtitle nolines nonum posthead(\hline Panel C \\)  compress nogap ///
	stats(N r2_a, ///
	  fmt(%9.0gc %-9.3f) labels("N" "R2")) 	  

*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
** Table 3: Life satisfaction and bodyweight among children: OLS specifications 
*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

* Globals
global child "age_eval c.age_eval#c.age_eval nolders nyounger" 
global house "i.region lninc hsize i.f_inhouse meals"
global care  "i.hhead i.civil2 age_care sch_care cesd10_int smoke drink2 drug2 breastf dep_post "

local list1 tae_apariencia
local list2 eclis_total
local list3 obs_ill
local list4 tae_apariencia eclis_total obs_ill
local se vce(cluster region)

* Z-BMI
est clear
foreach c of numlist 0 1 {
	eststo: reg lsat $child $house $care  zbmi_child  if sexchild == `c', `se'
	scalar base = _b[zbmi_child]
	foreach x in list1 list2 list3 list4 {
		eststo: reg lsat $child $house $care  zbmi_child  ``x'' if sexchild == `c', `se'
		scalar new          = _b[zbmi_child]
        estadd scalar share = (base - new) / base * 100
	}
}
esttab using "$out/olst.tex", replace f  ///
		b(3) se(3) star(* 0.10 ** 0.05 *** 0.01) ///
		keep(zbmi_child tae_apariencia eclis_total obs_ill) coeflabel(zbmi_child "z-BMI" tae_apariencia "BIS" eclis_total "Bullying" obs_ill "Bad health") ///
		booktabs nonotes collabels(none) alignment(D{.}{.}{-1}) longtable nolines posthead(\hline Panel A \\) compress nogap nodepvar nomtitle  ///
		stats(N r2_a share, ///
				fmt(%9.0gc %-9.3f %-9.0f) labels("N" "R2" "\shortstack[l]{\% Reduction \\ in bodyweight \\ coefficient}")) ///
		mgroups("Girls" "Boys", pattern(1 0 0 0 0 1 0 0 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) 
	
* Obese
est clear
foreach c of numlist 0 1 {
	eststo: reg lsat $child $house $care obese if sexchild == `c', `se'
	scalar base = _b[obese]
	foreach x in list1 list2 list3 list4 {
		eststo: reg lsat $child $house $care  obese   ``x'' if sexchild == `c', `se'
		scalar new          = _b[obese]
        estadd scalar share = (base - new) / base * 100
	}
}
esttab using "$out/olst.tex", append f  ///
		b(3) se(3) star(* 0.10 ** 0.05 *** 0.01) ///
		keep(obese tae_apariencia eclis_total obs_ill) coeflabel(obese "Obese" tae_apariencia "BIS" eclis_total "Bullying" obs_ill "Bad health") ///
		label booktabs nonotes collabels(none) alignment(D{.}{.}{-1}) longtable nomtitle nolines nonum posthead(\hline Panel B \\)  compress nogap ///
		stats(N r2_a share, ///
				fmt(%9.0gc %-9.3f %-9.0f) labels("N" "R2" "\shortstack[l]{\% Reduction \\ in bodyweight \\ coefficient}")) 
	  
* Weight
est clear
foreach c of numlist 0 1 {
	eststo: reg lsat $child $house $care  weight height   if sexchild == `c', `se'
	scalar base = _b[weight]
	foreach x in list1 list2 list3 list4 {
		eststo: reg lsat $child $house $care  weight height    ``x'' if sexchild == `c', `se'
		scalar new          = _b[weight]
        estadd scalar share = (base - new) / base * 100
	}
}	  
esttab using "$out/olst.tex", append f  ///
		b(3) se(3) star(* 0.10 ** 0.05 *** 0.01) ///
		keep(weight height tae_apariencia eclis_total obs_ill) coeflabel(weight "Weight" height "Height" tae_apariencia "BIS" eclis_total "Bullying" obs_ill "Bad Health") ///
		label booktabs nonotes collabels(none) alignment(D{.}{.}{-1}) longtable nomtitle nolines nonum posthead(\hline Panel C \\)  compress nogap ///
		stats(N r2_a share, ///
				fmt(%9.0gc %-9.3f %-9.0f) labels("N" "R2" "\shortstack[l]{\% Reduction \\ in bodyweight \\ coefficient}")) 
	  	
*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
** Figure 2: Non-linear relationship between bodyweight and life satisfaction 
*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

global child "age_eval c.age_eval#c.age_eval nolders nyounger" 
global house "i.region lninc hsize i.f_inhouse meals"
global care  "i.hhead i.civil2 age_care sch_care cesd10_int smoke drink2 drug2 breastf dep_post "

reg lsat $child $house $care zbmi_child  c.zbmi_child#c.zbmi_child if sexchild == 0
margins, dydx(zbmi_child) at(zbmi_child =(-3(0.5)3))
marginsplot, scheme(s1mono) yline(0) title("A: Results for girls") xtitle("Standardized values of BMI") ytitle("Effect of z-BMI")
graph save "$out/quad-girls", replace

reg lsat $child $house $care zbmi_child  c.zbmi_child#c.zbmi_child if sexchild == 1
margins, dydx(zbmi_child) at(zbmi_child =(-3(0.5)3))
marginsplot, scheme(s1mono) yline(0) title("B: Results for boys")  xtitle("Standardized values of BMI") ytitle("Effect of z-BMI")
graph save "$out/quad-boys", replace

gr combine "$out/quad-girls" "$out/quad-boys", col(2) iscale(0.5)
graph export "$out/quad-both.eps", replace

	  
*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
** Figure 3: Kinky least squares estimates for z-BMI and obesity  
*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

*Globals for controls
gen age2 = age_eval * age_eval
tabulate region, gen(rg)

global child "age_eval age2 nolders nyounger" 
global house "rg2-rg15 lninc hsize f_inhouse meals"
global care  "hhead cv2-cv5 age_care sch_care cesd10_int smoke drink2 drug2 breastf dep_post"

kinkyreg lsat   $child $house $care  (zbmi_child)                       		if sexchild == 0, range(-0.7 0.7) inference(zbmi_child) small  ///
          twoway(, ytitle("Impact of z-BMI") yline(0) xtitle("{&rho}{subscript:w{&epsilon}}") scheme(s1mono) title("KLS estimates of z-BMI for girls")) 
graph save "$out/kinky1", replace
		  
kinkyreg lsat   $child $house $care  (obese)                       		        if sexchild == 0, range(-0.7 0.7) inference(obese) small  ///
          twoway(, ytitle("Impact of obesity") yline(0) xtitle("{&rho}{subscript:w{&epsilon}}") scheme(s1mono) title("KLS estimates of obesity for girls")) 
graph save "$out/kinky2", replace
		  
kinkyreg lsat   height $child $house $care  (weight)                       		if sexchild == 0, range(-0.7 0.7) inference(weight) small  ///
          twoway(, ytitle("Impact of weight") yline(0) xtitle("{&rho}{subscript:w{&epsilon}}") scheme(s1mono) title("KLS estimates of weight for girls")) 
graph save "$out/kinky3", replace
		  
kinkyreg lsat   $child $house $care  (zbmi_child)                       		if sexchild == 1, range(-0.7 0.7) inference(zbmi_child) small  ///
          twoway(, ytitle("Impact of z-BMI") yline(0) xtitle("{&rho}{subscript:w{&epsilon}}") scheme(s1mono) title("KLS estimates of z-BMI for boys")) 
graph save "$out/kinky4", replace
		  
kinkyreg lsat   $child $house $care  (obese)                       		        if sexchild == 1, range(-0.7 0.7) inference(obese) small  ///
          twoway(, ytitle("Impact of obesity") yline(0) xtitle("{&rho}{subscript:w{&epsilon}}") scheme(s1mono) title("KLS estimates of obesity for boys")) 
graph save "$out/kinky5", replace
		  
kinkyreg lsat   height $child $house $care  (weight)                       		if sexchild == 1, range(-0.7 0.7) inference(weight) small  ///
          twoway(, ytitle("Impact of weight") yline(0) xtitle("{&rho}{subscript:w{&epsilon}}") scheme(s1mono) title("KLS estimates of weight for boys")) 
graph save "$out/kinky6", replace	

gr combine "$out/kinky1" "$out/kinky4" "$out/kinky2" "$out/kinky5", col(2) iscale(0.5)	  
graph export "$out/kinky.eps", replace

*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
** Figure 4: Kinky least squares estimates for z-BMI and obesity  
*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

reg bmi_child Lbmi_care c.Lbmi_care#c.Lbmi_care $child $house $care if sexchild == 1
eststo boys: margins, at(Lbmi_care=(15(5)60)) post

reg bmi_child Lbmi_care c.Lbmi_care#c.Lbmi_care $child $house $care if sexchild == 0
eststo girls: margins, at(Lbmi_care=(15(5)60)) post

coefplot boys girls, vertical recast(connected) ///
      scheme(s1mono) xtitle("Mother's BMI in 2012") ytitle("Predicted child's BMI in 2017") nolabel ///
	  xlabel(1 "15" 2 "20" 3 "25" 4 "30" 5 "35" 6 "40" 7 "45" 8 "50" 9 "55" 10 "60") title ("BMI")
graph save "$out/mon-bmi", replace

reg zbmi_child Lbmi_care c.Lbmi_care#c.Lbmi_care $child $house $care if sexchild == 1
eststo boys: margins, at(Lbmi_care=(15(5)60)) post

reg zbmi_child Lbmi_care c.Lbmi_care#c.Lbmi_care $child $house $care if sexchild == 0
eststo girls: margins, at(Lbmi_care=(15(5)60)) post

coefplot boys girls, vertical recast(connected) ///
      scheme(s1mono) xtitle("Mother's BMI in 2012") ytitle("Predicted child's z-BMI in 2017") nolabel ///
	  xlabel(1 "15" 2 "20" 3 "25" 4 "30" 5 "35" 6 "40" 7 "45" 8 "50" 9 "55" 10 "60") title ("z-BMI")
graph save "$out/mon-zbmi", replace


probit obese  Lbmi_care c.Lbmi_care#c.Lbmi_care $child $house $care if sexchild == 1
eststo boys: margins, at(Lbmi_care=(15(5)60)) post

probit obese  Lbmi_care c.Lbmi_care#c.Lbmi_care $child $house $care if sexchild == 0
eststo girls: margins, at(Lbmi_care=(15(5)60)) post

coefplot boys girls, vertical recast(connected) ///
      scheme(s1mono) xtitle("Mother's BMI in 2012") ytitle("Predicted probability of obesity in 2017") nolabel ///
	  xlabel(1 "15" 2 "20" 3 "25" 4 "30" 5 "35" 6 "40" 7 "45" 8 "50" 9 "55" 10 "60") title ("Obesity")
graph save "$out/mon-obesity", replace


reg weight height Lbmi_care c.Lbmi_care#c.Lbmi_care $child $house $care if sexchild == 1
eststo boys: margins, at(Lbmi_care=(15(5)60)) post

reg weight height Lbmi_care c.Lbmi_care#c.Lbmi_care $child $house $care if sexchild == 0
eststo girls: margins, at(Lbmi_care=(15(5)60)) post

coefplot boys girls, vertical recast(connected) ///
      scheme(s1mono) xtitle("Mother's BMI in 2012") ytitle("Predicted child's weight in 2017") nolabel ///
	  xlabel(1 "15" 2 "20" 3 "25" 4 "30" 5 "35" 6 "40" 7 "45" 8 "50" 9 "55" 10 "60") title ("Weight")
graph save "$out/mon-weight", replace

gr combine "$out/mon-bmi" "$out/mon-zbmi" "$out/mon-obesity" "$out/mon-weight", col(2) iscale(0.5)
graph export "$out/monotonicity.eps", replace


*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
** Table 4: Association between children's LS and mother's BMI
*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


*Globals for controls
global child "age_eval c.age_eval#c.age_eval nolders nyounger" 
global house "i.region lninc hsize i.f_inhouse meals"
global care  "i.hhead i.civil2 age_care sch_care cesd10_int smoke drink2 drug2 breastf dep_post "
local se vce(cluster region)

est clear
local se vce(cluster region)
foreach c of numlist 0 1 {
	foreach x of varlist zbmi_child obese {
		eststo: reg lsat $child $house $care `x' Lbmi_care if sexchild == `c', `se'
	}
}
esttab using "$out/exclusion.tex", replace ///
	b(3) se(3) star(* 0.10 ** 0.05 *** 0.01) ///
	booktabs nonotes collabels(none) alignment(D{.}{.}{-1}) longtable compress nogap nodepvar nomtitle  ///
	stats(N, fmt(%9.0gc) labels("N")) ///
    mgroups("Girls" "Boys", pattern(1 0 1 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))  ///
    order(Lbmi_care) ///
	title("Association between children's LS and mother's BMI\label{tab:exclusion}") ///
	keep(Lbmi_care zbmi_child obese) coeflabel(Lbmi_care "Lagged mother's BMI" zbmi_child "Child's z-BMI" obese "Obese") 

	
*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
** Table 5: Balance of covariates between non-obese and obese mother
*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

* Was the mother obese during 2012?
gen obese_m = (Lbmi_care >= 30) if Lbmi_care != .

global children "age_eval nolders nyounger " 
global household "f_inhouse lninc hsize meals"
global maternal "sch_care age_care hhead cv* cesd10_int smoke drink2 drug2 breastf dep_post"


eststo clear
sort sexchild
eststo girls: estpost ttest $children $household $maternal  if sexchild  == 0 & flag1 == 1, by(obese_m) 
eststo boys:  estpost ttest $children $household $maternal  if sexchild  == 1 & flag1 == 1, by(obese_m)
esttab girls boys using "$out/balanced.tex", replace cells("mu_1(fmt(3)) mu_2(fmt(3)) b(fmt(3) star)") ///
           collabels("\multicolumn{1}{c}{Non-Obese}" "\multicolumn{1}{c}{Obese}" "\multicolumn{1}{c}{Difference}" "\multicolumn{1}{c}{Non-Obese}" "\multicolumn{1}{c}{Obese}" "\multicolumn{1}{c}{Difference}", span ) ///
		   star(* 0.10 ** 0.05 *** 0.01) ///
		   mgroups("Girls" "Boys", pattern(1 1) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))  ///
		   title("Balance of covariates between non-obese and obese mother\label{tab:balanced}") ///
		 coeflabels( ///
				  age_eval "Child's age in months" ///
				  nolders "Number of older siblings" ///
				  nyounger "Number of younger siblings" ///
				  lninc "ln(Household income)" ///
				  hsize "Household size" ///
				  sch_care "Mother's education (in years)" ///
				  age_care "Mother's age" ///
				  cv1 "Married" ///
				  cv2 "Cohabitating" ///
				  cv3 "Separated/divorce" ///
				  cv4 "Single" ///
				  cv5 "Widowed" ///
				  hhead "Household head" ///
				  f_inhouse "Father in the house" ///
				  cesd10_int "Mother's depression" ///
				  meals "Number of meals with family" ///
				  dep_post "Post-partum depression" ///
				  smoke "Smoked during pregancy" ///
				  drug2 "Used drugs during pregnancy" ///
				  drink2 "Drunk during pregnancy" ///
				  breastf "Month of breastfeeding") ///
		  nonumbers compress nogap booktabs nolabel longtable
		  
	
*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
** Table 6: Life satisfaction and bodyweight: IV specifications
*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

global child "age_eval c.age_eval#c.age_eval nolders nyounger" 
global house "i.region lninc hsize i.f_inhouse meals"
global care  "i.hhead i.civil2 age_care sch_care cesd10_int smoke drink2 drug2 breastf dep_post "

local list1 tae_apariencia
local list2 eclis_total
local list3 obs_ill
local list4 tae_apariencia eclis_total obs_ill
local se cluster(region)


* Z-BMI
est clear
foreach c of numlist 0 1 {
	eststo: ivreg2 lsat $child $house $care  (zbmi_child = Lbmi_care)  if sexchild == `c', `se'
	scalar base = _b[zbmi_child]
	foreach x in list1 list2 list3 list4 {
		eststo: ivreg2 lsat $child $house $care  (zbmi_child = Lbmi_care)  ``x'' if sexchild == `c', `se'
		scalar new          = _b[zbmi_child]
        estadd scalar share = (base - new) / base * 100
	}
}
esttab using "$out/iv2.tex", replace f  ///
		b(3) se(3) star(* 0.10 ** 0.05 *** 0.01) ///
		keep(zbmi_child tae_apariencia eclis_total obs_ill) coeflabel(zbmi_child "z-BMI" tae_apariencia "BIS" eclis_total "Bullying" obs_ill "Bad health") ///
		booktabs nonotes collabels(none) alignment(D{.}{.}{-1}) longtable nolines posthead(\hline Panel A \\) compress nogap nodepvar nomtitle  ///
		stats(N widstat share, ///
				fmt(%9.0gc %-9.3f %-9.0f) labels("N" "F-stat" "\shortstack[l]{\% Reduction \\ in bodyweight \\ coefficient}")) ///
		mgroups("Girls" "Boys", pattern(1 0 0 0 0 1 0 0 0 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span}))
	
* Obese
est clear
foreach c of numlist 0 1 {
	eststo: ivreg2 lsat $child $house $care  (obese = Lbmi_care)  if sexchild == `c', `se'
	scalar base = _b[obese]
	foreach x in list1 list2 list3 list4 {
		eststo: ivreg2 lsat $child $house $care  (obese = Lbmi_care)  ``x'' if sexchild == `c', `se'
		scalar new          = _b[obese]
        estadd scalar share = (base - new) / base * 100
	}
}
esttab using "$out/iv2.tex", append f  ///
		b(3) se(3) star(* 0.10 ** 0.05 *** 0.01) ///
		keep(obese tae_apariencia eclis_total obs_ill) coeflabel(obese "Obese" tae_apariencia "BIS" eclis_total "Bullying" obs_ill "Bad health") ///
		label booktabs nonotes collabels(none) alignment(D{.}{.}{-1}) longtable nomtitle nolines nonum posthead(\hline Panel B \\)   compress nogap ///
		stats(N widstat share, ///
				fmt(%9.0gc %-9.3f %-9.0f) labels("N" "F-stat" "\shortstack[l]{\% Reduction \\ in bodyweight \\ coefficient}"))

* Weight
est clear
foreach c of numlist 0 1 {
	eststo: ivreg2 lsat height $child $house $care  (weight = Lbmi_care)  if sexchild == `c', `se'
	scalar base = _b[weight]
	foreach x in list1 list2 list3 list4 {
		eststo: ivreg2 lsat height $child $house $care  (weight = Lbmi_care)  ``x'' if sexchild == `c', `se'
		scalar new          = _b[weight]
        estadd scalar share = (base - new) / base * 100
	}
}
esttab using "$out/iv2.tex", append f  ///
		b(3) se(3) star(* 0.10 ** 0.05 *** 0.01) ///
		keep(weight height tae_apariencia eclis_total obs_ill) coeflabel(weight "Weight" height "Height" tae_apariencia "BIS" eclis_total "Bullying" obs_ill "Bad health") ///
		label booktabs nonotes collabels(none) alignment(D{.}{.}{-1}) longtable nomtitle nolines nonum posthead(\hline Panel C \\)  postfoot(\hline)  compress nogap ///
		stats(N widstat share, ///
				fmt(%9.0gc %-9.3f %-9.0f) labels("N" "F-stat" "\shortstack[l]{\% Reduction \\ in bodyweight \\ coefficient}"))
	  
****** END *********


	  


